@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2016-2022 Univention GmbH
+# Copyright 2016-2023 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -59,7 +59,7 @@ actions = {
 
 
 def run(_umc_instance: Instance) -> None:
-	if ucr.is_true('diagnostic/check/disable/59_ldap_server_name') or ucr.get('server/role') != 'memberserver':
+	if ucr.get('server/role') != 'memberserver':
 		return
 
 	ldap_server_name = ucr.get('ldap/server/name')
